@@ -3,6 +3,7 @@
 #include <stdio.h>
 #include <math.h>
 #include <string.h>
+#include <libgen.h>
 
 #include "../src/param.h"
 #include "../src/tdef.h"
@@ -97,8 +98,8 @@ char **argv;
   struct star_particle *sp, *lastsp;
   
   
-  if(argc<2) {
-    fprintf(stderr,"Use: %s AMIGA_file\n",*argv);
+  if(argc<3) {
+    fprintf(stderr,"Use: %s inputfile outputfile\n",*argv);
     exit(1);
   }
   
@@ -107,8 +108,7 @@ char **argv;
   printf("\n  read simulation data and convert to TIPSY format\n");
   printf("\n====================================================\n\n");
   
-  strcpy(outdata,argv[1]);
-  strcat(outdata,".tipsy");
+  strcpy(outdata,argv[2]);
   
   /*====================================================
    * READ INPUT FILE
@@ -123,9 +123,9 @@ char **argv;
   v_fac = io.header.boxsize * H0 / io.header.a_current;   // km/sec  -> gives a*\dot{x} as AHF uses a^2*\dot{x} internally
   m_fac = io.header.pmass;                                // Msun/h
   fprintf(stderr,"+ conversion factors (AHF internal -> physical):\n");
-  fprintf(stderr,"   positions:   %lf\n",x_fac);
-  fprintf(stderr,"   velocities:  %lf\n",v_fac);
-  fprintf(stderr,"   masses:      %lf\n",m_fac);
+  fprintf(stderr,"   positions:   %g\n",x_fac);
+  fprintf(stderr,"   velocities:  %g\n",v_fac);
+  fprintf(stderr,"   masses:      %g\n",m_fac);
   
   // values for GASOLINE-CLUES runs
   x2tipsy  = 1.0/x_fac;                                                 // Mpc/h  -> TIPSY internal units
@@ -134,9 +134,9 @@ char **argv;
   m2tipsy  = 1./(2.77467e11*pow(x_fac,3));                              // Msun/h -> TIPSY internal units
   
   fprintf(stderr,"+ conversion factors (physical -> TIPSY internal):\n");
-  fprintf(stderr,"   positions:   %lf\n",x2tipsy);
-  fprintf(stderr,"   velocities:  %lf\n",v2tipsy);
-  fprintf(stderr,"   masses:      %lf\n",m2tipsy);
+  fprintf(stderr,"   positions:   %g\n",x2tipsy);
+  fprintf(stderr,"   velocities:  %g\n",v2tipsy);
+  fprintf(stderr,"   masses:      %g\n",m2tipsy);
   
   // we will only use one conversion factor:
   x_fac *= x2tipsy;
