@@ -170,7 +170,8 @@ io_mtng_open(io_logging_t log,
 #endif
   
 	/* Glue the files into the MTNG structure */
-	f->files = (io_mtng_t *)malloc( sizeof(io_mtng_t)*(f->numfiles));
+	//f->files = (io_mtng_t *)malloc( sizeof(io_mtng_t)*(f->numfiles));
+	f->files = (io_gizmo_struct_t **)malloc( sizeof(io_gizmo_struct_t*)*(f->numfiles));
 	if (f->files == NULL) {
     io_logging_memfatal(log,  "io_mtng structure (2)");
 		for (i=0; i<f->numfiles; i++)
@@ -259,9 +260,10 @@ io_mtng_open(io_logging_t log,
        * A DUMMY INTERFACE TO A MTNG FILE.
        * TODO
        */
-      (f->files)[i] = io_tng_open(log, fnames[i], swapped, mode, f->size+1);
+      //(f->files)[i] = io_tng_open(log, fnames[i], swapped, mode, f->size+1);
+      (f->files)[i] = (io_gizmo_t)io_tng_open(log, fnames[i], swapped, mode, f->size+1);
 #else
-      (f->files)[i] = io_tng_open(log, fnames[i], swapped, mode, reader);
+      (f->files)[i] = (io_gizmo_t)io_tng_open(log, fnames[i], swapped, mode, reader);
 #endif
       
       if ((f->files)[i] == NULL) {
@@ -271,7 +273,8 @@ io_mtng_open(io_logging_t log,
         free(fnames);
         while (i>0) {
           i--;
-          io_tng_close(log, &((f->files)[i]));
+          //io_tng_close(log, &((f->files)[i]));
+          io_tng_close(log, (io_tng_struct_t **)&((f->files)[i]));
         }
         free(f->stem);
         free(f->path);
@@ -291,7 +294,8 @@ io_mtng_open(io_logging_t log,
   /* we nevertheless need to generate all the file structures ready to receive the broadcast */
   else {
     for (i=0; i<f->numfiles; i++) {
-      ((f->files)[i]) = (io_mtng_t)calloc(sizeof(io_mtng_struct_t),1);
+      //((f->files)[i]) = (io_mtng_t)calloc(sizeof(io_mtng_struct_t),1);
+      ((f->files)[i]) = (io_gizmo_t)calloc(sizeof(io_gizmo_struct_t),1);
       ((f->files)[i])->fname = NULL;
     }
   }
@@ -365,7 +369,8 @@ io_mtng_close(io_logging_t log,
 
 	/* free() all related structures and fclose() the files (in case the file pointer is not NULL) */
 	for (i=0; i<(*f)->numfiles; i++)
-		io_tng_close(log, &(((*f)->files)[i]));
+		//io_tng_close(log, &(((*f)->files)[i]));
+		io_tng_close(log, (io_tng_struct_t **)&(((*f)->files)[i]));
   
 	if((*f)->files) free((*f)->files);
   if((*f)->stem)  free((*f)->stem);
@@ -401,7 +406,8 @@ io_mtng_init(io_logging_t log,
   if(f->rank_mycomm == 0) {
 #endif
     for (i=0; i<f->numfiles; i++) {
-      io_tng_init(log, (f->files)[i]);
+      //io_tng_init(log, (f->files)[i]);
+      io_tng_init(log, (io_tng_t)(f->files)[i]);
       f->multimass |= f->files[i]->multimass;
       f->no_part += f->files[i]->no_part;
     }
@@ -410,13 +416,15 @@ io_mtng_init(io_logging_t log,
   else {
     /* allocate memory on this MPI task to hold the header for each file */
     for (i=0; i<f->numfiles; i++) {
-      ((f->files)[i])->header = (io_mtng_header_t)malloc((size_t)MTNG_HEADER_SIZE+1);
+      //((f->files)[i])->header = (io_mtng_header_t)malloc((size_t)MTNG_HEADER_SIZE+1);
+      ((f->files)[i])->header = (io_gizmo_header_t)malloc((size_t)TNG_HEADER_SIZE+1);
     }
   }
     
   /* Broadcast the header of each file from rank==0 to all other MPI tasks */
   for (i=0; i<f->numfiles; i++) {
-    MPI_Bcast(((f->files)[i])->header,((size_t)MTNG_HEADER_SIZE+1),MPI_BYTE,0,f->mycomm);
+    //MPI_Bcast(((f->files)[i])->header,((size_t)MTNG_HEADER_SIZE+1),MPI_BYTE,0,f->mycomm);
+    MPI_Bcast(((f->files)[i])->header,((size_t)TNG_HEADER_SIZE+1),MPI_BYTE,0,f->mycomm);
 
     /* io_mtng_init() also set some more relevant values in f */
     MPI_Bcast(&(((f->files)[i])->multimass),           sizeof(int8_t),   MPI_BYTE, 0, f->mycomm);
@@ -503,7 +511,8 @@ io_mtng_readpart_raw(io_logging_t log,
 		 * tmporary long variable for that and copy it over to the 64
 		 * bit integer afterwards.
 		 */
-		if (io_tng_get(log, f->files[i], IO_FILE_GET_NOPART, &tmp) != true) {
+		//if (io_tng_get(log, f->files[i], IO_FILE_GET_NOPART, &tmp) != true) {
+		if (io_tng_get(log, (io_tng_t)f->files[i], IO_FILE_GET_NOPART, &tmp) != true) {
 			io_logging_fatal(log, "Could not get number of particles from %s", f->files[i]->fname);
 		}
 		partinfile = (uint64_t)tmp;
@@ -572,7 +581,8 @@ io_mtng_readpart_raw(io_logging_t log,
 #else /* (defined WITH_MPI && defined NCPUREADING_EQ_NFILES) */
     
 		/* Now read the particles */
-		partread = io_tng_readpart_raw(log, f->files[i], pskip_file, pread_file, strg);
+		//partread = io_tng_readpart_raw(log, f->files[i], pskip_file, pread_file, strg);
+		partread = io_tng_readpart_raw(log, (io_tng_t)f->files[i], pskip_file, pread_file, strg);
 		if (pread_file != partread) {
 			io_logging_fatal(log, "Something went wrong. Wanted to read %" PRIu64 " particles, but got %" PRIu64 ". Aborting.",
                        pread_file, partread);
@@ -883,7 +893,8 @@ io_mtng_log(io_logging_t log, io_mtng_t f)
 		io_logging_msg(log, INT32_C(5),
 		               "  ---> File %"PRIi32 ":",
 		               i);
-		io_tng_log(log, (f->files)[i]);
+		//io_tng_log(log, (f->files)[i]);
+		io_tng_log(log, (io_tng_t)(f->files)[i]);
 	}
 
 	return;
@@ -900,7 +911,8 @@ io_mtng_resetscale(io_logging_t log,
 		return;
 
 	for (i=0; i<f->numfiles; i++) {
-		io_tng_resetscale(log, f->files[i], posscale, weightscale);
+		//io_tng_resetscale(log, f->files[i], posscale, weightscale);
+		io_tng_resetscale(log, (io_tng_t)f->files[i], posscale, weightscale);
 	}
 	f->posscale = posscale;
 	f->weightscale = weightscale;
