@@ -1373,7 +1373,8 @@ local_get_block_pos(io_logging_t log,
     
     io_logging_msg(log, INT32_C(2), "local_get_block_pos(): part type %d: allocated %" PRIu64 " bytes for CommBuffer", type, num_bytes);
     
-    io_util_readhdf5_gizmo(log, f, "Coordinates", type, num_elements, detected_type, hdf5_grp, CommBuffer);
+    //io_util_readhdf5_gizmo(log, f, "Coordinates", type, num_elements, detected_type, hdf5_grp, CommBuffer);
+    io_util_readhdf5_gizmo(log, (io_gizmo_t)f, "Coordinates", type, num_elements, detected_type, hdf5_grp, CommBuffer);
     
     io_logging_msg(log, INT32_C(2), "local_get_block_pos(): part type %d: read particles into CommBuffer", type);
     
@@ -1503,7 +1504,8 @@ local_get_block_vel(io_logging_t log,
     
     io_logging_msg(log, INT32_C(2), "local_get_block_vel(): part type %d: allocated %" PRIu64 " bytes for CommBuffer", type, num_bytes);
     
-    io_util_readhdf5_gizmo(log, f, "Velocities", type, num_elements, detected_type, hdf5_grp, CommBuffer);
+    //io_util_readhdf5_gizmo(log, f, "Velocities", type, num_elements, detected_type, hdf5_grp, CommBuffer);
+    io_util_readhdf5_gizmo(log, (io_gizmo_t)f, "Velocities", type, num_elements, detected_type, hdf5_grp, CommBuffer);
     
     /* Loop over the particle positions */
     for (i = 0; i < num_elements * f->header->np[type]; i += num_elements) {
@@ -1616,7 +1618,8 @@ local_get_block_id(io_logging_t log,
     
     io_logging_msg(log, INT32_C(2), "local_get_block_id(): part type %d: allocated %" PRIu64 " bytes for CommBuffer", type, num_bytes);
     
-    io_util_readhdf5_gizmo(log, f, "ParticleIDs", type, 1, detected_type, hdf5_grp, CommBuffer);
+    //io_util_readhdf5_gizmo(log, f, "ParticleIDs", type, 1, detected_type, hdf5_grp, CommBuffer);
+    io_util_readhdf5_gizmo(log, (io_gizmo_t)f, "ParticleIDs", type, 1, detected_type, hdf5_grp, CommBuffer);
     
     /* Loop over the particle IDs */
     for (i = 0; i < f->header->np[type]; i++) {
@@ -1745,7 +1748,8 @@ f->mmass = fweight; \
         return UINT64_C(0);
       }
       
-      io_util_readhdf5_gizmo(log, f, "Masses", type, 1, detected_type, hdf5_grp, CommBuffer);
+      //io_util_readhdf5_gizmo(log, f, "Masses", type, 1, detected_type, hdf5_grp, CommBuffer);
+      io_util_readhdf5_gizmo(log, (io_gizmo_t)f, "Masses", type, 1, detected_type, hdf5_grp, CommBuffer);
       
       /* Loop over the particle massess */
       for (i = 0; i < f->header->np[type]; i++) {
@@ -1848,7 +1852,8 @@ local_get_block_u(io_logging_t log,
       
       io_logging_msg(log, INT32_C(2), "local_get_block_u(): part type %d: allocated %" PRIu64 " bytes for CommBuffer", type, num_bytes);
       
-      io_util_readhdf5_gizmo(log, f, "InternalEnergy", type, 1, detected_type, hdf5_grp, CommBuffer);
+      //io_util_readhdf5_gizmo(log, f, "InternalEnergy", type, 1, detected_type, hdf5_grp, CommBuffer);
+      io_util_readhdf5_gizmo(log, (io_gizmo_t)f, "InternalEnergy", type, 1, detected_type, hdf5_grp, CommBuffer);
     }
     
     /* Loop over the particles */
@@ -1977,7 +1982,8 @@ local_get_block_z(io_logging_t log,
       
       io_logging_msg(log, INT32_C(2), "local_get_block_z(): part type %d: allocated %" PRIu64 " bytes for CommBuffer", type, num_bytes);
       
-      io_util_readhdf5_gizmo(log, f, (char *)dataset_name, type, num_elements, detected_type, hdf5_grp, CommBuffer);
+      //io_util_readhdf5_gizmo(log, f, (char *)dataset_name, type, num_elements, detected_type, hdf5_grp, CommBuffer);
+      io_util_readhdf5_gizmo(log, (io_gizmo_t)f, (char *)dataset_name, type, num_elements, detected_type, hdf5_grp, CommBuffer);
       
       /* Loop over the particle positions */
       for (i = 0; i < num_elements * f->header->np[type]; i += num_elements) {
@@ -2080,7 +2086,8 @@ local_get_block_age(io_logging_t log,
       io_logging_msg(log, INT32_C(2), "local_get_block_age(): part type %d: allocated %" PRIu64 " bytes for CommBuffer", type, num_bytes);
       
       /* StellarAge should be the proper tag in the HDF5 file */
-      io_util_readhdf5_gizmo(log, f, (char *)dataset_name, type, 1, detected_type, hdf5_grp, CommBuffer);
+      //io_util_readhdf5_gizmo(log, f, (char *)dataset_name, type, 1, detected_type, hdf5_grp, CommBuffer);
+      io_util_readhdf5_gizmo(log, (io_gizmo_t)f, (char *)dataset_name, type, 1, detected_type, hdf5_grp, CommBuffer);
     }
     else if (f->header->np[type] != 0 )
     {
